===
NuO
===
.. image:: https://travis-ci.org/akshitgrover/NuO.svg?branch=master
    :target: https://travis-ci.org/akshitgrover/NuO
.. image:: http://hits.dwyl.io/akshitgrover/NuO.svg
    :target: http://hits.dwyl.io/akshitgrover/NuO

Static website templating engine, Generates HTML pages using .nuo template files and data in JSON files.

Installation
============
::

    `pip install nuo`
